==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_MapPoint.pm <==
package WebGUI::i18n::Dutch::Asset_MapPoint;
use utf8;
our $I18N = {
  'address1' => {
    'lastUpdated' => '1271835129',
    'message' => 'De eerste regel van dit adres.'
  },
  'address1 description' => {
    'lastUpdated' => '1248782466',
    'message' => 'Eerste adres regel'
  },
  'address1 label' => {
    'lastUpdated' => '1248782478',
    'message' => 'Adres 1'
  },
  'address2' => {
    'lastUpdated' => '1271835137',
    'message' => 'De tweede regel van dit adres.'
  },
  'address2 description' => {
    'lastUpdated' => '1248782490',
    'message' => 'Tweede adres regel'
  },
  'address2 label' => {
    'lastUpdated' => '1248782500',
    'message' => 'Adres 2'
  },
  'address3' => {
    'lastUpdated' => '1271835147',
    'message' => 'De derde regel van dit adres.'
  },
  'assetName' => {
    'lastUpdated' => '1248782516',
    'message' => 'Kaart lokatie'
  },
  'city' => {
    'lastUpdated' => '1271835165',
    'message' => 'De stad van dit punt.'
  },
  'city description' => {
    'lastUpdated' => '1248782548',
    'message' => 'De stad waar de lokatie zich bevindt'
  },
  'city label' => {
    'lastUpdated' => '1248782557',
    'message' => 'Stad'
  },
  'country' => {
    'lastUpdated' => '1271835177',
    'message' => 'Het land van dit punt.'
  },
  'country description' => {
    'lastUpdated' => '1248782576',
    'message' => 'Het land waar de lokatie zich bevindt'
  },
  'country label' => {
    'lastUpdated' => '1248782584',
    'message' => 'Land'
  },
  'currentPhoto' => {
    'lastUpdated' => '1271835364',
    'message' => 'HTML code voor het tonen van een recent toegevoegde foto.'
  },
  'edit template' => {
    'lastUpdated' => '1271938004',
    'message' => 'Kaart locatie sjabloon voor bewerken'
  },
  'email' => {
    'lastUpdated' => '1271938022',
    'message' => 'Het e-mailadres van dit punt.'
  },
  'email description' => {
    'lastUpdated' => '1248782607',
    'message' => 'Het e-mailadres van de lokatie'
  },
  'email label' => {
    'lastUpdated' => '1248782616',
    'message' => 'E-mail'
  },
  'fax' => {
    'lastUpdated' => '1271938039',
    'message' => 'Het faxnummer bij dit punt'
  },
  'fax description' => {
    'lastUpdated' => '1248782632',
    'message' => 'Het faxnummer van de lokatie'
  },
  'fax label' => {
    'lastUpdated' => '1248782642',
    'message' => 'Fax'
  },
  'form_address1' => {
    'lastUpdated' => '1271938068',
    'message' => 'Een tekstveld voor een deel van een adres.'
  },
  'form_address2' => {
    'lastUpdated' => '1271938075',
    'message' => 'Een tekstveld voor een deel van een adres.'
  },
  'form_address3' => {
    'lastUpdated' => '1271938081',
    'message' => 'Een tekstveld voor een deel van een adres.'
  },
  'form_city' => {
    'lastUpdated' => '1271938101',
    'message' => 'Een tekstveld voor het invoeren van een stad.'
  },
  'form_country' => {
    'lastUpdated' => '1271938109',
    'message' => 'Een tekstveld voor het invoeren van een land.'
  },
  'form_email' => {
    'lastUpdated' => '1271938119',
    'message' => 'Een tekstveld voor het invoeren van een e-mailadres.'
  },
  'form_fax' => {
    'lastUpdated' => '1271938128',
    'message' => 'Een tekstveld voor het invoeren van een faxnummer.'
  },
  'form_footer' => {
    'lastUpdated' => '1272463648',
    'message' => 'HTML code om het formulier mee te be&euml;indigen.'
  },
  'form_header' => {
    'lastUpdated' => '1272463662',
    'message' => 'HTML code om het formulier mee te beginnen.'
  },
  'form_phone' => {
    'lastUpdated' => '1271938146',
    'message' => 'Een tekstveld voor het invoeren van een telefoonnummer.'
  },
  'form_region' => {
    'lastUpdated' => '1271938157',
    'message' => 'Een tekstveld voor het invoeren van een regio.'
  },
  'form_storageIdPhoto' => {
    'lastUpdated' => '1272463829',
    'message' => 'Een invoerveld om een fotobestand voor deze locatie toe te voegen.'
  },
  'form_submit' => {
    'lastUpdated' => '1272463682',
    'message' => 'Een knop om het formulier in te zenden.'
  },
  'form_synopsis' => {
    'lastUpdated' => '1271938180',
    'message' => 'Een tekstveld voor het invoeren van een korte beschrijving.'
  },
  'form_title' => {
    'lastUpdated' => '1272463716',
    'message' => 'Een tekst veld voor het invoeren van de titel.'
  },
  'form_website' => {
    'lastUpdated' => '1272463747',
    'message' => 'Een tekst veld voor het invoeren van een URL wat geralteerd is aan de locatie.'
  },
  'form_zipCode' => {
    'lastUpdated' => '1272463769',
    'message' => 'Een tekst veld voor het invoeren van de postcode van het adres.'
  },
  'latitude' => {
    'lastUpdated' => '1271836780',
    'message' => 'De breedtegraag van dit punt.'
  },
  'latitude description' => {
    'lastUpdated' => '1248782672',
    'message' => 'Latitude van de lokatie'
  },
  'latitude label' => {
    'lastUpdated' => '1248782682',
    'message' => 'Latitude'
  },
  'longitude' => {
    'lastUpdated' => '1271836768',
    'message' => 'De lengtegraad van dit punt.'
  },
  'longitude description' => {
    'lastUpdated' => '1248782695',
    'message' => 'Longitude van de lokatie'
  },
  'longitude label' => {
    'lastUpdated' => '1248782705',
    'message' => 'Longitude'
  },
  'map point asset template variables' => {
    'lastUpdated' => '1272463787',
    'message' => 'Kaart locatie sjabloon variabelen'
  },
  'phone' => {
    'lastUpdated' => '1271836023',
    'message' => 'Het telefoonnummer van dit punt.'
  },
  'phone description' => {
    'lastUpdated' => '1248782721',
    'message' => 'Het telefoonnummer van de lokatie'
  },
  'phone label' => {
    'lastUpdated' => '1248782729',
    'message' => 'Telefoon'
  },
  'region' => {
    'lastUpdated' => '1271836010',
    'message' => 'De regio, staat of provincie van dit punt.'
  },
  'state description' => {
    'lastUpdated' => '1248782752',
    'message' => 'De staat of provincie waar de lokatie zich bevindt'
  },
  'state label' => {
    'lastUpdated' => '1248782766',
    'message' => 'Provincie/staat'
  },
  'storageIdPhoto' => {
    'lastUpdated' => '1271835990',
    'message' => 'De locatie van de opslag van de foto van dit punt.'
  },
  'storageIdPhoto description' => {
    'lastUpdated' => '1248782779',
    'message' => 'Een foto van de lokatie'
  },
  'storageIdPhoto label' => {
    'lastUpdated' => '1248782786',
    'message' => 'Foto'
  },
  'website' => {
    'lastUpdated' => '1271835942',
    'message' => 'De website van dit punt.'
  },
  'website description' => {
    'lastUpdated' => '1248782804',
    'message' => 'Website van of over de lokatie'
  },
  'website label' => {
    'lastUpdated' => '1248782816',
    'message' => 'Website URL'
  },
  'zipCode' => {
    'lastUpdated' => '1271835932',
    'message' => 'De postcode van dit punt.'
  },
  'zipCode description' => {
    'lastUpdated' => '1248782854',
    'message' => 'De postcode van de omgeving waar de lokatie zich bevindt'
  },
  'zipCode label' => {
    'lastUpdated' => '1248782866',
    'message' => 'Postcode'
  }
}
;

1;

==> webgui_7.9.33.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_MapPoint.pm <==
package WebGUI::i18n::Dutch::Asset_MapPoint;
use utf8;
our $I18N = {
  'address1' => {
    'lastUpdated' => '1271835129',
    'message' => 'De eerste regel van dit adres.'
  },
  'address1 description' => {
    'lastUpdated' => '1248782466',
    'message' => 'Eerste adres regel'
  },
  'address1 label' => {
    'lastUpdated' => '1248782478',
    'message' => 'Adres 1'
  },
  'address2' => {
    'lastUpdated' => '1271835137',
    'message' => 'De tweede regel van dit adres.'
  },
  'address2 description' => {
    'lastUpdated' => '1248782490',
    'message' => 'Tweede adres regel'
  },
  'address2 label' => {
    'lastUpdated' => '1248782500',
    'message' => 'Adres 2'
  },
  'address3' => {
    'lastUpdated' => '1271835147',
    'message' => 'De derde regel van dit adres.'
  },
  'assetName' => {
    'lastUpdated' => '1248782516',
    'message' => 'Kaart lokatie'
  },
  'city' => {
    'lastUpdated' => '1271835165',
    'message' => 'De stad van dit punt.'
  },
  'city description' => {
    'lastUpdated' => '1248782548',
    'message' => 'De stad waar de lokatie zich bevindt'
  },
  'city label' => {
    'lastUpdated' => '1248782557',
    'message' => 'Stad'
  },
  'country' => {
    'lastUpdated' => '1271835177',
    'message' => 'Het land van dit punt.'
  },
  'country description' => {
    'lastUpdated' => '1248782576',
    'message' => 'Het land waar de lokatie zich bevindt'
  },
  'country label' => {
    'lastUpdated' => '1248782584',
    'message' => 'Land'
  },
  'currentPhoto' => {
    'lastUpdated' => '1271835364',
    'message' => 'HTML code voor het tonen van een recent toegevoegde foto.'
  },
  'edit template' => {
    'lastUpdated' => '1271938004',
    'message' => 'Kaart locatie sjabloon voor bewerken'
  },
  'email' => {
    'lastUpdated' => '1271938022',
    'message' => 'Het e-mailadres van dit punt.'
  },
  'email description' => {
    'lastUpdated' => '1248782607',
    'message' => 'Het e-mailadres van de lokatie'
  },
  'email label' => {
    'lastUpdated' => '1248782616',
    'message' => 'E-mail'
  },
  'fax' => {
    'lastUpdated' => '1271938039',
    'message' => 'Het faxnummer bij dit punt'
  },
  'fax description' => {
    'lastUpdated' => '1248782632',
    'message' => 'Het faxnummer van de lokatie'
  },
  'fax label' => {
    'lastUpdated' => '1248782642',
    'message' => 'Fax'
  },
  'form_address1' => {
    'lastUpdated' => '1271938068',
    'message' => 'Een tekstveld voor een deel van een adres.'
  },
  'form_address2' => {
    'lastUpdated' => '1271938075',
    'message' => 'Een tekstveld voor een deel van een adres.'
  },
  'form_address3' => {
    'lastUpdated' => '1271938081',
    'message' => 'Een tekstveld voor een deel van een adres.'
  },
  'form_city' => {
    'lastUpdated' => '1271938101',
    'message' => 'Een tekstveld voor het invoeren van een stad.'
  },
  'form_country' => {
    'lastUpdated' => '1271938109',
    'message' => 'Een tekstveld voor het invoeren van een land.'
  },
  'form_email' => {
    'lastUpdated' => '1271938119',
    'message' => 'Een tekstveld voor het invoeren van een e-mailadres.'
  },
  'form_fax' => {
    'lastUpdated' => '1271938128',
    'message' => 'Een tekstveld voor het invoeren van een faxnummer.'
  },
  'form_footer' => {
    'lastUpdated' => '1272463648',
    'message' => 'HTML code om het formulier mee te be&euml;indigen.'
  },
  'form_header' => {
    'lastUpdated' => '1272463662',
    'message' => 'HTML code om het formulier mee te beginnen.'
  },
  'form_phone' => {
    'lastUpdated' => '1271938146',
    'message' => 'Een tekstveld voor het invoeren van een telefoonnummer.'
  },
  'form_region' => {
    'lastUpdated' => '1271938157',
    'message' => 'Een tekstveld voor het invoeren van een regio.'
  },
  'form_storageIdPhoto' => {
    'lastUpdated' => '1272463829',
    'message' => 'Een invoerveld om een fotobestand voor deze locatie toe te voegen.'
  },
  'form_submit' => {
    'lastUpdated' => '1272463682',
    'message' => 'Een knop om het formulier in te zenden.'
  },
  'form_synopsis' => {
    'lastUpdated' => '1271938180',
    'message' => 'Een tekstveld voor het invoeren van een korte beschrijving.'
  },
  'form_title' => {
    'lastUpdated' => '1272463716',
    'message' => 'Een tekst veld voor het invoeren van de titel.'
  },
  'form_website' => {
    'lastUpdated' => '1272463747',
    'message' => 'Een tekst veld voor het invoeren van een URL wat geralteerd is aan de locatie.'
  },
  'form_zipCode' => {
    'lastUpdated' => '1272463769',
    'message' => 'Een tekst veld voor het invoeren van de postcode van het adres.'
  },
  'latitude' => {
    'lastUpdated' => '1271836780',
    'message' => 'De breedtegraag van dit punt.'
  },
  'latitude description' => {
    'lastUpdated' => '1248782672',
    'message' => 'Latitude van de lokatie'
  },
  'latitude label' => {
    'lastUpdated' => '1248782682',
    'message' => 'Latitude'
  },
  'longitude' => {
    'lastUpdated' => '1271836768',
    'message' => 'De lengtegraad van dit punt.'
  },
  'longitude description' => {
    'lastUpdated' => '1248782695',
    'message' => 'Longitude van de lokatie'
  },
  'longitude label' => {
    'lastUpdated' => '1248782705',
    'message' => 'Longitude'
  },
  'map point asset template variables' => {
    'lastUpdated' => '1272463787',
    'message' => 'Kaart locatie sjabloon variabelen'
  },
  'phone' => {
    'lastUpdated' => '1271836023',
    'message' => 'Het telefoonnummer van dit punt.'
  },
  'phone description' => {
    'lastUpdated' => '1248782721',
    'message' => 'Het telefoonnummer van de lokatie'
  },
  'phone label' => {
    'lastUpdated' => '1248782729',
    'message' => 'Telefoon'
  },
  'region' => {
    'lastUpdated' => '1271836010',
    'message' => 'De regio, staat of provincie van dit punt.'
  },
  'state description' => {
    'lastUpdated' => '1248782752',
    'message' => 'De staat of provincie waar de lokatie zich bevindt'
  },
  'state label' => {
    'lastUpdated' => '1248782766',
    'message' => 'Provincie/staat'
  },
  'storageIdPhoto' => {
    'lastUpdated' => '1271835990',
    'message' => 'De locatie van de opslag van de foto van dit punt.'
  },
  'storageIdPhoto description' => {
    'lastUpdated' => '1248782779',
    'message' => 'Een foto van de lokatie'
  },
  'storageIdPhoto label' => {
    'lastUpdated' => '1248782786',
    'message' => 'Foto'
  },
  'user defined variables' => {
    'lastUpdated' => '1298566695',
    'message' => 'Anders dan het collaboratiesysteem, gebruiken mappunten geen voorgedefineerde velden door de door de gebruiker gedefinieerde velden. In plaats daarvan wordt elk formulier veld wat nodig is de naam gegeven van de userDefined variabele die gebruikt wordt. WebGUI handelt dit verder af.'
  },
  'userDefined1' => {
    'lastUpdated' => '1298566734',
    'message' => 'Gebruiker gedefini&amp;euml;erd als 1'
  },
  'userDefined2' => {
    'lastUpdated' => '1298566740',
    'message' => 'Gebruiker gedefini&amp;euml;erd als 2'
  },
  'userDefined3' => {
    'lastUpdated' => '1298566745',
    'message' => 'Gebruiker gedefini&amp;euml;erd als 3'
  },
  'userDefined4' => {
    'lastUpdated' => '1298566751',
    'message' => 'Gebruiker gedefini&amp;euml;erd als 4'
  },
  'userDefined5' => {
    'lastUpdated' => '1298566757',
    'message' => 'Gebruiker gedefini&amp;euml;erd als 5'
  },
  'website' => {
    'lastUpdated' => '1271835942',
    'message' => 'De website van dit punt.'
  },
  'website description' => {
    'lastUpdated' => '1248782804',
    'message' => 'Website van of over de lokatie'
  },
  'website label' => {
    'lastUpdated' => '1248782816',
    'message' => 'Website URL'
  },
  'zipCode' => {
    'lastUpdated' => '1271835932',
    'message' => 'De postcode van dit punt.'
  },
  'zipCode description' => {
    'lastUpdated' => '1248782854',
    'message' => 'De postcode van de omgeving waar de lokatie zich bevindt'
  },
  'zipCode label' => {
    'lastUpdated' => '1248782866',
    'message' => 'Postcode'
  }
}
;

1;
